<?php
/**
 * The header for our theme
 *
 * @subpackage lz-interior-decor
 * @since 1.0
 * @version 0.1
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js no-svg">
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php if ( function_exists( 'wp_body_open' ) ) {
    wp_body_open();
} else {
    do_action( 'wp_body_open' );
}?>

<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'lz-interior-decor' ); ?></a>

	<div class="top-header">
		<div class="container">	
			<div class="row">
				<div class="col-lg-6 col-md-5">
					<div class="top">
						<?php if( get_theme_mod( 'lz_interior_decor_mail') != '') { ?>	
					        <span class="col-org"><a href="mailto:<?php echo esc_attr( get_theme_mod('lz_interior_decor_mail','') ); ?>"><i class="fas fa-envelope"></i><?php echo esc_html( get_theme_mod('lz_interior_decor_mail','') ); ?></a></span>
					    <?php } ?>
					</div>
				</div>
				<div class="col-lg-4 col-md-4">
					<div class="social-icons">
						<?php if( get_theme_mod( 'lz_interior_decor_facebook_url') != '') { ?>
			              <a href="<?php echo esc_url( get_theme_mod( 'lz_interior_decor_facebook_url','' ) ); ?>"><i class="fab fa-facebook-f" aria-hidden="true"></i><span class="screen-reader-text"><?php esc_html_e( 'Facebook','lz-interior-decor' );?></span></a>
			            <?php } ?>
			            <?php if( get_theme_mod( 'lz_interior_decor_twitter_url') != '') { ?>
			              <a href="<?php echo esc_url( get_theme_mod( 'lz_interior_decor_twitter_url','' ) ); ?>"><i class="fab fa-twitter"></i><span class="screen-reader-text"><?php esc_html_e( 'Twitter','lz-interior-decor' );?></span></a>
			            <?php } ?>
			            <?php if( get_theme_mod( 'lz_interior_decor_insta_url') != '') { ?>
			              <a href="<?php echo esc_url( get_theme_mod( 'lz_interior_decor_insta_url','' ) ); ?>"><i class="fab fa-instagram"></i><span class="screen-reader-text"><?php esc_html_e( 'Instagram','lz-interior-decor' );?></span></a>
			            <?php } ?>
			            <?php if( get_theme_mod( 'lz_interior_decor_linkedin_url') != '') { ?>
			              <a href="<?php echo esc_url( get_theme_mod( 'lz_interior_decor_linkedin_url','' ) ); ?>"><i class="fab fa-linkedin-in"></i><span class="screen-reader-text"><?php esc_html_e( 'Linkedin','lz-interior-decor' );?></span></a>
			            <?php } ?>
					</div>	
				</div>
				<div class="col-lg-2 col-md-3 p-0">
					<div class="call">
				 	<?php if( get_theme_mod( 'lz_interior_decor_call') != '') { ?>
				        <span class="col-org"><a href="tel:<?php echo esc_attr( get_theme_mod('lz_interior_decor_call','') ); ?>"><i class="fas fa-phone"></i><?php echo esc_html( get_theme_mod('lz_interior_decor_call','') ); ?></a></span>
				    <?php } ?>
					</div>
				</div>
			</div>
		</div>
	</div>

	<header role="banner" id="header">
	    <div class="menu-section">
			<div class="container">
				<div class="main-top">
					<div class="row padd0">
						<div class="col-lg-4 col-md-4 col-9">
							<div class="logo">
						        <?php if ( has_custom_logo() ) : ?>
							        <div class="site-logo"><?php the_custom_logo(); ?></div>
							    <?php endif; ?>
					            <?php if (get_theme_mod('lz_interior_decor_show_site_title',true)) {?>
							        <?php $blog_info = get_bloginfo( 'name' ); ?>
							        <?php if ( ! empty( $blog_info ) ) : ?>
							            <?php if ( is_front_page() && is_home() ) : ?>
								            <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
							        	<?php else : ?>
						            		<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
							            <?php endif; ?>
							        <?php endif; ?>
							    <?php }?>
					        	<?php if (get_theme_mod('lz_interior_decor_show_tagline',true)) {?>
							        <?php
							        $description = get_bloginfo( 'description', 'display' );
							        if ( $description || is_customize_preview() ) :
							          ?>
								        <p class="site-description">
								            <?php echo esc_html($description); ?>
								        </p>
							        <?php endif; ?>
							    <?php }?>
						    </div>
						</div>
						<?php if (has_nav_menu('primary')){ ?>
							<div class="col-lg-8 col-md-8 col-3">
								<div class="toggle-menu responsive-menu">
						            <button onclick="lz_interior_decor_open()" role="tab" class="mobile-menu"><i class="fas fa-bars"></i><span class="screen-reader-text"><?php esc_html_e('Open Menu','lz-interior-decor'); ?></span></button>
						        </div>
								<div id="sidelong-menu" class="nav sidenav">
					                <nav id="primary-site-navigation" class="nav-menu" role="navigation" aria-label="<?php esc_attr_e( 'Top Menu', 'lz-interior-decor' ); ?>">
					                  <?php 
					                    wp_nav_menu( array( 
					                      'theme_location' => 'primary',
					                      'container_class' => 'main-menu-navigation clearfix' ,
					                      'menu_class' => 'clearfix',
					                      'items_wrap' => '<ul id="%1$s" class="%2$s mobile_nav">%3$s</ul>',
					                      'fallback_cb' => 'wp_page_menu',
					                    ) ); 
					                  ?>
					                  <a href="javascript:void(0)" class="closebtn responsive-menu" onclick="lz_interior_decor_close()"><i class="fas fa-times"></i><span class="screen-reader-text"><?php esc_html_e('Close Menu','lz-interior-decor'); ?></span></a>
					                </nav>
					            </div>
							</div>
						<?php }?>
				     	<div class="clearfix"></div>
					</div>
				</div>
			</div>
		</div>
	</header>

	<div class="site-content-contain">
		<div id="content" class="site-content">